@@ -122,9 +122,6 @@ PyArrayObject *pyvector(PyObject *objin)  {
 /* ==== Create 1D Carray from PyArray ======================
     Assumes PyArray is contiguous in memory.             */
 double *pyvector_to_Carrayptrs(PyArrayObject *arrayin)  {
-	int i,n;
-	
-	n=arrayin->dimensions[0];
 	return (double *) arrayin->data;  /* pointer to arrayin data as double */
 }
 /* ==== Check that PyArrayObject is a double (Float) type and a vector ==============
@@ -1032,10 +1029,10 @@ Py_polyeval(PyObject *self, PyObject *args)
     PyErr_SetString(polymodError, "The order must be bigger than 0.");
   if ((PyArray_NDIM(py_rs) > 1) || (PyArray_NDIM(py_alpha) > 1) || (PyArray_NDIM(py_beta) > 1))
     PyErr_SetString(polymodError, "The array provided must be 1 dimensional.");
-  if (( PyArray_SHAPE(py_alpha)[0] < n ) || ( PyArray_SHAPE(py_beta)[0] < n ))
+  if (( py_alpha->dimensions[0] < n ) || ( py_beta->dimensions[0] < n ))
     PyErr_SetString(polymodError, "The recurrence coefficeints must be more than n.");
   
-  dims[0] = PyArray_SHAPE(py_rs)[0];
+  dims[0] = py_rs->dimensions[0];
 
   // PyArray to C
   rs = pyvector_to_Carrayptrs(py_rs);
@@ -1149,10 +1146,10 @@ Py_vandermonde(PyObject *self, PyObject *args)
     PyErr_SetString(polymodError, "The order must be bigger than 0.");
   if ((PyArray_NDIM(py_rs) > 1) || (PyArray_NDIM(py_alpha) > 1) || (PyArray_NDIM(py_beta) > 1))
     PyErr_SetString(polymodError, "The array provided must be 1 dimensional.");
-  if (( PyArray_SHAPE(py_alpha)[0] < n ) || ( PyArray_SHAPE(py_beta)[0] < n ))
+  if (( py_alpha->dimensions[0] < n ) || ( py_beta->dimensions[0] < n ))
     PyErr_SetString(polymodError, "The recurrence coefficeints must be more than n.");
   
-  dims[0] = PyArray_SHAPE(py_rs)[0];
+  dims[0] = py_rs->dimensions[0];
   dims[1] = n+1;
 
   // PyArray to C
